@@ -867,7 +867,7 @@ ecb_gtasks_save_component_sync (ECalMetaBackend *meta_backend,
 				EConflictResolution conflict_resolution,
 				const GSList *instances, /* ECalComponent * */
 				const gchar *extra,
-				guint32 opflags,
+				ECalOperationFlags opflags,
 				gchar **out_new_uid,
 				gchar **out_new_extra,
 				GCancellable *cancellable,
@@ -962,7 +962,7 @@ ecb_gtasks_remove_component_sync (ECalMetaBackend *meta_backend,
 				  const gchar *uid,
 				  const gchar *extra,
 				  const gchar *object,
-				  guint32 opflags,
+				  ECalOperationFlags opflags,
 				  GCancellable *cancellable,
 				  GError **error)
 {
