@@ -1188,6 +1188,9 @@ main (gint argc,
 	g_type_init ();
 #endif
 	g_test_init (&argc, &argv, NULL);
+	g_test_bug_base ("https://gitlab.gnome.org/GNOME/evolution-data-server/");
+
+	tcu_read_args (argc, argv);
 
 	/* Ensure that the client and server get the same locale */
 	g_assert (g_setenv ("LC_ALL", "en_US.UTF-8", TRUE));
@@ -1218,5 +1221,5 @@ main (gint argc,
 	g_test_add ("/EBookCache/Offline/DeleteResync", TCUFixture, &closure,
 		tcu_fixture_setup, test_offline_delete_resync, tcu_fixture_teardown);
 
-	return e_test_server_utils_run_full (0);
+	return e_test_server_utils_run_full (argc, argv, 0);
 }
